@@ -86,11 +86,10 @@ AObootBetween <- function(
 
       data.BS$factor1 <- factor(data.BS$factor1, levels = levels.b1)
 
-
       ## Control for all cells
       boots.con <- table(data.BS$factor1)
 
-      if (any(boots.con == 0) == TRUE) {
+      if (any(boots.con == 0) | length(boots.con) < length(levels.b1)) {
         next
       }
 
@@ -369,7 +368,9 @@ AObootBetween <- function(
       ## Control for all cells
       boots.con <- table(data.BS$factor1, data.BS$factor2)
 
-      if (any(boots.con == 0) == TRUE) {
+      if (any(
+        boots.con == 0) | ncol(boots.con) < length(levels.b2) |
+        nrow(boots.con) < length(levels.b1)) {
         next
       }
 
